<?php
// Require the Composer autoload file to include the Faker library
require 'vendor/autoload.php';

use Faker\Factory;

// Function to generate a unique filename
function getUniqueFilename($baseName, $extension) {
    $counter = 0;
    $filename = "{$baseName}{$counter}.{$extension}";
    
    while (file_exists($filename)) {
        $counter++;
        $filename = "{$baseName}{$counter}.{$extension}";
    }
    
    return $filename;
}

// Set the base filename and extension
$baseFilename = 'church_database';
$extension = 'csv';
$filename = getUniqueFilename($baseFilename, $extension);

// Open the file for writing
$file = fopen($filename, 'w');

// Write the header
fputcsv($file, ['id', 'email', 'name', 'password', 'status', 'online', 'last_login', 'participants', 'last_seen', 'uid', 'title', 'country']);

// Create a Faker instance
$faker = Factory::create();

// Define titles
$titles = ['Pastor', 'Reverend', 'Bishop', 'Evangelist', 'Minister', 'Father'];

// Suggested email domains for custom emails
$custom_domains = [
    'churchdomain.org', 'faithministry.net', 'gospelhub.com',
    'blessedcommunity.org', 'holychurch.com', 'ministryconnect.org', 
    'soulwin.com', 'compassionchurch.org', 'righteouspath.com',
    'globalministry.net', 'savior.com'
];

// Popular email providers
$popular_providers = [
    'gmail.com', 'yahoo.com', 'hotmail.com', 'outlook.com',
    'live.com', 'icloud.com', 'mail.com'
];

// Unique records
$usedNames = [];

for ($i = 0; $i < 100000; $i++) {
    // Generate a unique ID for each row (or you could let the database handle it)
    $id = $i + 1;
    
    // Ensure unique names
    do {
        $first_name = $faker->firstName;
        $last_name = $faker->lastName;
        $full_name = $first_name . ' ' . $last_name;
    } while (in_array($full_name, $usedNames));
    
    $usedNames[] = $full_name;
    $title = $titles[array_rand($titles)];
    
    // Decide on email domain type (15% custom domains)
    $email_domain = (mt_rand(1, 100) <= 15) ? $custom_domains[array_rand($custom_domains)] : $popular_providers[array_rand($popular_providers)];

    // Generate diverse email formats
    $formats = [
        strtolower($first_name) . $last_name . '@' . $email_domain,
        strtolower($last_name) . '.' . strtolower($first_name) . '@' . $email_domain,
        strtolower($first_name[0]) . strtolower($last_name) . '@' . $email_domain,
        strtolower($first_name) . '_' . strtolower($last_name) . '@' . $email_domain,
        strtolower($first_name) . $last_name[0] . '@' . $email_domain,
        strtolower($last_name) . $first_name . '@' . $email_domain,
        strtolower($first_name) . '-' . strtolower($last_name) . '@' . $email_domain,
    ];
    
    $email = $formats[array_rand($formats)];
    $country = $faker->country;
    
    // Empty values for fields that are not generated
    $password = null;
    $status = null;
    $online = null;
    $last_login = null;
    $participants = null;
    $last_seen = null;
    $uid = null;

    // Write the row to the CSV with the required fields
    fputcsv($file, [$id, $email, $full_name, $password, $status, $online, $last_login, $participants, $last_seen, $uid, $title, $country]);
}

// Close the file
fclose($file);

echo "CSV file '{$filename}' OGINI KWA 10k.";
?>
